
// --------------------------------------------------------
//  drbd-kernel-compat/cocci/bio_bi_bdev__no_present.cocci
// --------------------------------------------------------
@@
struct bio *b;
@@
// The only case where we really use bio->bi_bdev is when accessing its bd_disk.
// We can trivially change that to use the old bi_disk instead.
b->
- bi_bdev->bd_disk
+ bi_disk
@@
identifier m, ignored;
@@
static int drbd_compat_show(struct seq_file *m, void *ignored)
{
	...
+	seq_puts(m, "bio_bi_bdev__no_present\n");
	return 0;
}

// -----------------------------------------------------------
//  drbd-kernel-compat/cocci/blk_alloc_disk__no_present.cocci
// -----------------------------------------------------------
@@
expression node;
fresh identifier q = "" ## "q";
identifier f, disk, device;
symbol out_no_io_page, out_no_disk;
@@
f(...) {
...
struct drbd_device *device;
+ struct request_queue *q;
...
- disk = blk_alloc_disk(node);
+ q = blk_alloc_queue(node);
+ if (!q) {
+	goto out_no_q;
+ }
+ device->rq_queue = q;
+ disk = alloc_disk(1);
...
device->vdisk = disk;
- device->rq_queue = disk->queue;
...
- disk->minors = 1;
+ disk->queue = q;
... when exists
out_no_io_page:
-	blk_cleanup_disk(disk);
+	put_disk(disk);
out_no_disk:
+	blk_cleanup_queue(q);
+ out_no_q:
...
}

@@
identifier f, device;
@@
f(...) {
...
struct drbd_device *device;
...
- blk_cleanup_disk(device->vdisk);
+ put_disk(device->vdisk);
+ blk_cleanup_queue(device->rq_queue);
...
}
@@
identifier m, ignored;
@@
static int drbd_compat_show(struct seq_file *m, void *ignored)
{
	...
+	seq_puts(m, "blk_alloc_disk__no_present\n");
	return 0;
}

// ------------------------------------------------------------
//  drbd-kernel-compat/cocci/submit_bio__no_returns_void.cocci
// ------------------------------------------------------------
@@
typedef blk_qc_t;
@@
- void
+ blk_qc_t
drbd_submit_bio(...)
{
	...
- 	return;
+	return BLK_QC_T_NONE;
}
@@
identifier m, ignored;
@@
static int drbd_compat_show(struct seq_file *m, void *ignored)
{
	...
+	seq_puts(m, "submit_bio__no_returns_void\n");
	return 0;
}

// ------------------------------------------------------------------
//  drbd-kernel-compat/cocci/disk_update_readahead__no_present.cocci
// ------------------------------------------------------------------
@@
identifier q;
identifier dev;
type T;
@@
T q = dev->rq_queue;
<...
- disk_update_readahead(dev->vdisk);
+ blk_queue_update_readahead(q);
...>
@@
identifier m, ignored;
@@
static int drbd_compat_show(struct seq_file *m, void *ignored)
{
	...
+	seq_puts(m, "disk_update_readahead__no_present\n");
	return 0;
}

// ------------------------------------------------------------------------
//  drbd-kernel-compat/cocci/struct_gendisk__no_has_backing_dev_info.cocci
// ------------------------------------------------------------------------
@@
struct drbd_device *d;
@@
d->ldev->backing_bdev->
- bd_disk->bdi
+ bd_disk->queue->backing_dev_info
@@
identifier m, ignored;
@@
static int drbd_compat_show(struct seq_file *m, void *ignored)
{
	...
+	seq_puts(m, "struct_gendisk__no_has_backing_dev_info\n");
	return 0;
}

// --------------------------------------------------------------------
//  drbd-kernel-compat/cocci/set_capacity_and_notify__no_present.cocci
// --------------------------------------------------------------------
@@
expression disk, size;
@@
- set_capacity_and_notify(disk, size);
+ set_capacity(disk, size);
+ revalidate_disk_size(disk, false);
@@
identifier m, ignored;
@@
static int drbd_compat_show(struct seq_file *m, void *ignored)
{
	...
+	seq_puts(m, "set_capacity_and_notify__no_present\n");
	return 0;
}

// --------------------------------------------------------
//  drbd-kernel-compat/cocci/nla_strscpy__no_present.cocci
// --------------------------------------------------------
@@
@@
- nla_strscpy
+ nla_strlcpy
@@
identifier m, ignored;
@@
static int drbd_compat_show(struct seq_file *m, void *ignored)
{
	...
+	seq_puts(m, "nla_strscpy__no_present\n");
	return 0;
}

// ----------------------------------------------------------------------
//  drbd-kernel-compat/cocci/queue_discard_zeroes_data__no_present.cocci
// ----------------------------------------------------------------------
@@
expression q;
@@
(
- !queue_discard_zeroes_data(q)
+ 1 /* !queue_discard_zeroes_data(q) */
|
- queue_discard_zeroes_data(q)
+ 0 /* queue_discard_zeroes_data(q) */
)
@@
identifier m, ignored;
@@
static int drbd_compat_show(struct seq_file *m, void *ignored)
{
	...
+	seq_puts(m, "queue_discard_zeroes_data__no_present\n");
	return 0;
}

// ----------------------------------------------------------------------
//  drbd-kernel-compat/cocci/part_stat_read__no_takes_block_device.cocci
// ----------------------------------------------------------------------
@@
expression part;
@@
// part_stat_read{,_accum} changed from taking a "struct hd_struct *" to a
// "struct block_device". Since this is a macro, and the "part" member on
// struct gendisk was not renamed but only changed its type, we miraculously
// only have to add a "&".
part_stat_read_accum(
- part
+ &part
, ...
 )
@@
identifier m, ignored;
@@
static int drbd_compat_show(struct seq_file *m, void *ignored)
{
	...
+	seq_puts(m, "part_stat_read__no_takes_block_device\n");
	return 0;
}

// ----------------------------------------------------
//  drbd-kernel-compat/cocci/bdgrab__yes_present.cocci
// ----------------------------------------------------
// If bdgrab is still around on this kernel, that implies that it still uses
// the "old" way of refcounting for partitions -- see 9d3b8813895d
// ("block: change the refcounting for partitions").
// As a consequence, we need to explicitly grab the partition before fsyncing it.
@@
expression part;
@@
- sync_blockdev(part);
+ struct block_device *bdev = bdgrab(part);
+ if (bdev)
+	sync_blockdev(bdev);
+ bdput(bdev);
@@
identifier m, ignored;
@@
static int drbd_compat_show(struct seq_file *m, void *ignored)
{
	...
+	seq_puts(m, "bdgrab__yes_present\n");
	return 0;
}

// ------------------------------------------------------------------
//  drbd-kernel-compat/cocci/gendisk_part0__no_is_block_device.cocci
// ------------------------------------------------------------------
@@
expression vdisk;
@@
- bdgrab(vdisk->part0)
+ bdget_disk(vdisk, 0)
@@
identifier m, ignored;
@@
static int drbd_compat_show(struct seq_file *m, void *ignored)
{
	...
+	seq_puts(m, "gendisk_part0__no_is_block_device\n");
	return 0;
}

// ---------------------------------------------------------
//  drbd-kernel-compat/cocci/bio_max_vecs__no_present.cocci
// ---------------------------------------------------------
@@
@@
- BIO_MAX_VECS
+ BIO_MAX_PAGES
@@
identifier m, ignored;
@@
static int drbd_compat_show(struct seq_file *m, void *ignored)
{
	...
+	seq_puts(m, "bio_max_vecs__no_present\n");
	return 0;
}

// -----------------------------------------------------------------------
//  drbd-kernel-compat/cocci/fs_dax_get_by_bdev__no_takes_start_off.cocci
// -----------------------------------------------------------------------
@@
expression b;
identifier off;
@@
- u64 off;
...
fs_dax_get_by_bdev(b
- , &off
 )
@@
identifier m, ignored;
@@
static int drbd_compat_show(struct seq_file *m, void *ignored)
{
	...
+	seq_puts(m, "fs_dax_get_by_bdev__no_takes_start_off\n");
	return 0;
}

// ---------------------------------------------------------
//  drbd-kernel-compat/cocci/add_disk__no_returns_int.cocci
// ---------------------------------------------------------
@ remove_add_disk_return @
identifier e;
identifier d;
identifier label;
@@
enum drbd_ret_code e = ...;
...
- e =
add_disk(d);
- if (e)
-	goto label;

@@
identifier remove_add_disk_return.label;
identifier label_after;
@@
-label:
-...
label_after:
@@
identifier m, ignored;
@@
static int drbd_compat_show(struct seq_file *m, void *ignored)
{
	...
+	seq_puts(m, "add_disk__no_returns_int\n");
	return 0;
}

// ------------------------------------------------------------
//  drbd-kernel-compat/cocci/bdev_nr_sectors__no_present.cocci
// ------------------------------------------------------------
@@
struct block_device *bd;
@@
- bdev_nr_sectors(bd)
+ get_capacity(bd->bd_disk)
@@
identifier m, ignored;
@@
static int drbd_compat_show(struct seq_file *m, void *ignored)
{
	...
+	seq_puts(m, "bdev_nr_sectors__no_present\n");
	return 0;
}

// -------------------------------------------------------------
//  drbd-kernel-compat/cocci/genhd_fl_no_part__no_present.cocci
// -------------------------------------------------------------
@@
@@
- GENHD_FL_NO_PART
+ GENHD_FL_NO_PART_SCAN
@@
identifier m, ignored;
@@
static int drbd_compat_show(struct seq_file *m, void *ignored)
{
	...
+	seq_puts(m, "genhd_fl_no_part__no_present\n");
	return 0;
}
